REPO = {
    "TC_GENERAL": {
        "cache_dir": "models",
        "type": "Classification",
        "license": "Open",
        "year": "2019",
        "model_path": "TC_GENERAL"
    },
    "TC_BANK": {
        "cache_dir": "models",
        "type": "Classification",
        "license": "Open",
        "year": "2019",
        "model_path": "TC_BANK"
    },
    "SA_GENERAL": {
        "cache_dir": "models",
        "type": "Sentiment",
        "license": "Open",
        "year": "2019",
        "model_path": "SA_GENERAL"
    },
    "SA_BANK": {
        "cache_dir": "models",
        "type": "Sentiment",
        "license": "Open",
        "year": "2019",
        "model_path": "SA_BANK"
    },
}
