REPO = {
    "AIVIVN2019-SA": {
        "cache_dir": "datasets/AIVIVN2019-SA",
        "type": "Categorized",
        "license": "Close",
        "year": "2019",
        "filepath": "",
        "url_filename": "AIVIVN2019_SA.zip?dl=1"
    },
    "VLSP2018-NER": {
        "cache_dir": "datasets/VLSP2018-NER",
        "type": "Tagged",
        "license": "Close",
        "year": "2018",
        "filepath": "",
        "url_filename": "VLSP2018-NER.zip?dl=1"
    },
    "VLSP2018-SA": {
        "cache_dir": "datasets/VLSP2018-SA",
        "type": "Categorized",
        "license": "Close",
        "year": "2018",
        "filepath": "",
        "url_filename": "VLSP2018_SA.zip?dl=1"
    },
    "VTB-CHUNK": {
        "cache_dir": "datasets/VTB-CHUNK",
        "type": "Tagged",
        "license": "Close",
        "year": "2017",
        "filepath": "",
        "url_filename": "VTB-CHUNK.zip?dl=1"
    },
    "UTS2017-BANK": {
        "cache_dir": "datasets/UTS2017-BANK",
        "type": "Categorized",
        "license": "Open",
        "year": "2017",
        "filepath": "",
        "url": "https://www.dropbox.com/s/xl8sof2i1c35n62/UTS2017_BANK.zip?dl=1",
        "url_filename": "UTS2017_BANK.zip?dl=1"
    },
    "VLSP2016-NER": {
        "cache_dir": "datasets/VLSP2016-NER",
        "type": "Tagged",
        "license": "Close",
        "year": "2016",
        "filepath": "",
        "url_filename": "VLSP2016-NER.zip?dl=1"
    },
    "VLSP2016-SA": {
        "cache_dir": "datasets/VLSP2016-SA",
        "type": "Categorized",
        "license": "Close",
        "year": "2016",
        "filepath": "",
        "url_filename": "VLSP2016_SA.zip?dl=1"
    },
    "VLSP2013-WTK": {
        "cache_dir": "datasets/VLSP2013-WTK",
        "type": "Tagged",
        "license": "Close",
        "year": "2013",
        "filepath": "",
        "url_filename": "VLSP2013-WTK.zip?dl=1"
    },
    "VLSP2013-POS": {
        "cache_dir": "datasets/VLSP2013-POS",
        "type": "Tagged",
        "license": "Close",
        "year": "2013",
        "filepath": "",
        "url_filename": "VLSP2013-POS.zip?dl=1"
    },
    "VNESES": {
        "cache_dir": "datasets/LTA",
        "type": "Plaintext",
        "license": "Open",
        "year": "2012",
        "filepath": "VNESEScorpus.txt",
        "url": "https://www.dropbox.com/s/ci2kktkhhq46cnh/VNESEcorpus.txt?dl=1",
        "url_filename": "VNESEcorpus.txt?dl=1"
    },
    "VNTQ_BIG": {
        "cache_dir": "datasets/LTA",
        "type": "Plaintext",
        "license": "Open",
        "year": "2012",
        "filepath": "VNTQcorpus-big.txt",
        "url": "https://www.dropbox.com/s/on6naf4una3r5ot/VNTQcorpus-big.txt?dl=1",
        "url_filename": "VNTQcorpus-big.txt?dl=1"
    },
    "VNTQ_SMALL": {
        "cache_dir": "datasets/LTA",
        "type": "Plaintext",
        "license": "Open",
        "year": "2012",
        "filepath": "VNTQcorpus-small.txt",
        "url": "https://www.dropbox.com/s/04wjlnpwe4a94lq/VNTQcorpus-small.txt?dl=1",
        "url_filename": "VNTQcorpus-small.txt?dl=1"
    },
    "VNTC": {
        "cache_dir": "datasets/VNTC",
        "type": "Categorized",
        "license": "Open",
        "year": "2007",
        "filepath": "",
        "url": "https://www.dropbox.com/s/4iw3xtnkd74h3pj/VNTC.zip?dl=1",
        "url_filename": "VNTC.zip?dl=1"
    }
}
